package server.command.commands;

import java.util.Collection;
import common.init.BlockRegistry;
import common.nbt.NBTTagCompound;
import common.tileentity.TileEntity;
import common.util.BlockPos;
import common.world.State;
import server.command.Command;
import server.command.CommandEnvironment;
import server.command.Executor;
import server.command.RunException;
import server.command.StringCompleter;
import server.world.WorldServer;

public class CommandBlock extends Command {
	public CommandBlock() {
		super("block");

		this.addString("block", false, new StringCompleter() {
			public Collection<String> complete(CommandEnvironment env) {
				return BlockRegistry.REGISTRY.getKeys();
			}
		});
		this.addBlockPos("position", true);
		this.addWorld("dim", true);
		
		this.addTag("tag", 't');
	}
	
	public Object exec(CommandEnvironment env, Executor exec, String block, BlockPos position, WorldServer world, NBTTagCompound tag) {
		State state = BlockRegistry.getFromIdName(block, null);
		if(state == null)
			throw new RunException("Block '%s' existiert nicht", block);
		boolean success = world.setState(position, state);
		if(tag != null) {
			TileEntity tile = world.getTileEntity(position);
			if(tile != null) {
				NBTTagCompound te = new NBTTagCompound();
				tile.writeToNBT(te);
				tag.setString("id", te.getString("id"));
	            tag.setInteger("x", position.getX());
	            tag.setInteger("y", position.getY());
	            tag.setInteger("z", position.getZ());
				te.merge(tag);
				TileEntity newTile = TileEntity.createAndLoadEntity(te);
				if(newTile != null) {
					world.removeTileEntity(position);
					world.setTileEntity(position, newTile);
					success = true;
				}
			}
		}
		if(success)
			exec.logConsole("%s bei %d, %d, %d in %s gesetzt", state.getBlock().getDisplay(), position.getX(), position.getY(), position.getZ(), world.dimension.getFormattedName(false));
		else
			exec.logConsole("Block wurde nicht verändert");
		return success;
	}
}
